**CUR 228 - 2010
Design guideline for soil laterally loaded piles**

The table presents a list of formulas from the CUR 228 guideline, tracking their implementation status
( :x: or :heavy_check_mark: ) and any pertinent remarks. The 'Object Name' column references the corresponding Python entities inside of Blueprints.

Total of 2 formulas present.

| Formula number |        Done        | Remarks | Object name               |
|:---------------|:------------------:|:--------|:--------------------------|
| 2.21           | :heavy_check_mark: |         | Form2Dot21MenardStiffness |
| 2.22           | :heavy_check_mark: |         | Form2Dot22MenardStiffness |
